# load needed packages
library('xlsx')
library('fitdistrplus')

# set working directory
setwd('/Users/markot/work/teaching/2017-18_AAU_DecisionSupportSystems/LectureNotes/05_ModelingUncertainty-2/code')

# load data from excel
raw_data <- read.xlsx('all-euro-data-2016-2017.xls', sheetIndex = 1)
x <- raw_data$FTHG

# visual inspection
hist(x)

# suggestion on distribution based on kurtosis and skewness
descdist(x, discrete = FALSE)

# fit various distributions
fit.nbinom <- fitdist(x, "nbinom", method = 'mme')
summary(fit.nbinom)
plot(fit.nbinom)

fit.beta <- fitdist(x/max(x), "beta", method = 'mme')
summary(fit.beta)
plot(fit.beta)

fit.pois <- fitdist(x, "pois", method = 'mme')
summary(fit.pois)
plot(fit.pois)

fit.norm <- fitdist(x, "norm", method = 'mme')
summary(fit.norm)
plot(fit.norm)

fit.gamma <- fitdist(x, "gamma", method = 'mme')
summary(fit.gamma)
plot(fit.gamma)

# compare the two discrete distributions
cdfcomp(list(fit.pois,  fit.nbinom), legendtext = c("poisson","negative binomial"))

# goodness-of-fit test
gofstat(list(fit.norm, fit.pois,  fit.nbinom, fit.gamma), fitnames = c("normal","poisson","negative binomial","gamma"))
